<?php

$mapping = array(
  'GuzzleHttp\RequestOptions' => __DIR__ . '/GuzzleHttp/RequestOptions.php',
  'GuzzleHttp\Middleware' => __DIR__ . '/GuzzleHttp/Middleware.php',
  'GuzzleHttp\Cookie\SetCookie' => __DIR__ . '/GuzzleHttp/Cookie/SetCookie.php',
  'GuzzleHttp\Cookie\CookieJar' => __DIR__ . '/GuzzleHttp/Cookie/CookieJar.php',
  'GuzzleHttp\Cookie\SessionCookieJar' => __DIR__ . '/GuzzleHttp/Cookie/SessionCookieJar.php',
  'GuzzleHttp\Cookie\CookieJarInterface' => __DIR__ . '/GuzzleHttp/Cookie/CookieJarInterface.php',
  'GuzzleHttp\Cookie\FileCookieJar' => __DIR__ . '/GuzzleHttp/Cookie/FileCookieJar.php',
  'GuzzleHttp\Exception\BadResponseException' => __DIR__ . '/GuzzleHttp/Exception/BadResponseException.php',
  'GuzzleHttp\Exception\ClientException' => __DIR__ . '/GuzzleHttp/Exception/ClientException.php',
  'GuzzleHttp\Exception\RequestException' => __DIR__ . '/GuzzleHttp/Exception/RequestException.php',
  'GuzzleHttp\Exception\ConnectException' => __DIR__ . '/GuzzleHttp/Exception/ConnectException.php',
  'GuzzleHttp\Exception\TransferException' => __DIR__ . '/GuzzleHttp/Exception/TransferException.php',
  'GuzzleHttp\Exception\GuzzleException' => __DIR__ . '/GuzzleHttp/Exception/GuzzleException.php',
  'GuzzleHttp\Exception\InvalidArgumentException' => __DIR__ . '/GuzzleHttp/Exception/InvalidArgumentException.php',
  'GuzzleHttp\Exception\ServerException' => __DIR__ . '/GuzzleHttp/Exception/ServerException.php',
  'GuzzleHttp\Exception\TooManyRedirectsException' => __DIR__ . '/GuzzleHttp/Exception/TooManyRedirectsException.php',
  'GuzzleHttp\Exception\SeekException' => __DIR__ . '/GuzzleHttp/Exception/SeekException.php',
  'GuzzleHttp\RetryMiddleware' => __DIR__ . '/GuzzleHttp/RetryMiddleware.php',
  'GuzzleHttp\MessageFormatter' => __DIR__ . '/GuzzleHttp/MessageFormatter.php',
  'GuzzleHttp\UriTemplate' => __DIR__ . '/GuzzleHttp/UriTemplate.php',
  'GuzzleHttp\functions_include' => __DIR__ . '/GuzzleHttp/functions_include.php',
  'GuzzleHttp\Psr7\LazyOpenStream' => __DIR__ . '/GuzzleHttp/Psr7/LazyOpenStream.php',
  'GuzzleHttp\Psr7\StreamDecoratorTrait' => __DIR__ . '/GuzzleHttp/Psr7/StreamDecoratorTrait.php',
  'GuzzleHttp\Psr7\UriNormalizer' => __DIR__ . '/GuzzleHttp/Psr7/UriNormalizer.php',
  'GuzzleHttp\Psr7\MultipartStream' => __DIR__ . '/GuzzleHttp/Psr7/MultipartStream.php',
  'GuzzleHttp\Psr7\Query' => __DIR__ . '/GuzzleHttp/Psr7/Query.php',
  'GuzzleHttp\Psr7\InflateStream' => __DIR__ . '/GuzzleHttp/Psr7/InflateStream.php',
  'GuzzleHttp\Psr7\MimeType' => __DIR__ . '/GuzzleHttp/Psr7/MimeType.php',
  'GuzzleHttp\Psr7\UploadedFile' => __DIR__ . '/GuzzleHttp/Psr7/UploadedFile.php',
  'GuzzleHttp\Psr7\Uri' => __DIR__ . '/GuzzleHttp/Psr7/Uri.php',
  'GuzzleHttp\Psr7\Header' => __DIR__ . '/GuzzleHttp/Psr7/Header.php',
  'GuzzleHttp\Psr7\functions_include' => __DIR__ . '/GuzzleHttp/Psr7/functions_include.php',
  'GuzzleHttp\Psr7\MessageTrait' => __DIR__ . '/GuzzleHttp/Psr7/MessageTrait.php',
  'GuzzleHttp\Psr7\LimitStream' => __DIR__ . '/GuzzleHttp/Psr7/LimitStream.php',
  'GuzzleHttp\Psr7\Utils' => __DIR__ . '/GuzzleHttp/Psr7/Utils.php',
  'GuzzleHttp\Psr7\FnStream' => __DIR__ . '/GuzzleHttp/Psr7/FnStream.php',
  'GuzzleHttp\Psr7\StreamWrapper' => __DIR__ . '/GuzzleHttp/Psr7/StreamWrapper.php',
  'GuzzleHttp\Psr7\ServerRequest' => __DIR__ . '/GuzzleHttp/Psr7/ServerRequest.php',
  'GuzzleHttp\Psr7\Message' => __DIR__ . '/GuzzleHttp/Psr7/Message.php',
  'GuzzleHttp\Psr7\functions' => __DIR__ . '/GuzzleHttp/Psr7/functions.php',
  'GuzzleHttp\Psr7\AppendStream' => __DIR__ . '/GuzzleHttp/Psr7/AppendStream.php',
  'GuzzleHttp\Psr7\UriResolver' => __DIR__ . '/GuzzleHttp/Psr7/UriResolver.php',
  'GuzzleHttp\Psr7\Rfc7230' => __DIR__ . '/GuzzleHttp/Psr7/Rfc7230.php',
  'GuzzleHttp\Psr7\Stream' => __DIR__ . '/GuzzleHttp/Psr7/Stream.php',
  'GuzzleHttp\Psr7\CachingStream' => __DIR__ . '/GuzzleHttp/Psr7/CachingStream.php',
  'GuzzleHttp\Psr7\PumpStream' => __DIR__ . '/GuzzleHttp/Psr7/PumpStream.php',
  'GuzzleHttp\Psr7\Response' => __DIR__ . '/GuzzleHttp/Psr7/Response.php',
  'GuzzleHttp\Psr7\NoSeekStream' => __DIR__ . '/GuzzleHttp/Psr7/NoSeekStream.php',
  'GuzzleHttp\Psr7\DroppingStream' => __DIR__ . '/GuzzleHttp/Psr7/DroppingStream.php',
  'GuzzleHttp\Psr7\Request' => __DIR__ . '/GuzzleHttp/Psr7/Request.php',
  'GuzzleHttp\Psr7\BufferStream' => __DIR__ . '/GuzzleHttp/Psr7/BufferStream.php',
  'GuzzleHttp\Utils' => __DIR__ . '/GuzzleHttp/Utils.php',
  'GuzzleHttp\ClientInterface' => __DIR__ . '/GuzzleHttp/ClientInterface.php',
  'GuzzleHttp\RedirectMiddleware' => __DIR__ . '/GuzzleHttp/RedirectMiddleware.php',
  'GuzzleHttp\PrepareBodyMiddleware' => __DIR__ . '/GuzzleHttp/PrepareBodyMiddleware.php',
  'GuzzleHttp\functions' => __DIR__ . '/GuzzleHttp/functions.php',
  'GuzzleHttp\Client' => __DIR__ . '/GuzzleHttp/Client.php',
  'GuzzleHttp\HandlerStack' => __DIR__ . '/GuzzleHttp/HandlerStack.php',
  'GuzzleHttp\Pool' => __DIR__ . '/GuzzleHttp/Pool.php',
  'GuzzleHttp\TransferStats' => __DIR__ . '/GuzzleHttp/TransferStats.php',
  'GuzzleHttp\Handler\CurlFactory' => __DIR__ . '/GuzzleHttp/Handler/CurlFactory.php',
  'GuzzleHttp\Handler\CurlHandler' => __DIR__ . '/GuzzleHttp/Handler/CurlHandler.php',
  'GuzzleHttp\Handler\StreamHandler' => __DIR__ . '/GuzzleHttp/Handler/StreamHandler.php',
  'GuzzleHttp\Handler\CurlMultiHandler' => __DIR__ . '/GuzzleHttp/Handler/CurlMultiHandler.php',
  'GuzzleHttp\Handler\CurlFactoryInterface' => __DIR__ . '/GuzzleHttp/Handler/CurlFactoryInterface.php',
  'GuzzleHttp\Handler\Proxy' => __DIR__ . '/GuzzleHttp/Handler/Proxy.php',
  'GuzzleHttp\Handler\EasyHandle' => __DIR__ . '/GuzzleHttp/Handler/EasyHandle.php',
  'GuzzleHttp\Handler\MockHandler' => __DIR__ . '/GuzzleHttp/Handler/MockHandler.php',
  'GuzzleHttp\Promise\EachPromise' => __DIR__ . '/GuzzleHttp/Promise/EachPromise.php',
  'GuzzleHttp\Promise\TaskQueue' => __DIR__ . '/GuzzleHttp/Promise/TaskQueue.php',
  'GuzzleHttp\Promise\functions_include' => __DIR__ . '/GuzzleHttp/Promise/functions_include.php',
  'GuzzleHttp\Promise\CancellationException' => __DIR__ . '/GuzzleHttp/Promise/CancellationException.php',
  'GuzzleHttp\Promise\PromiseInterface' => __DIR__ . '/GuzzleHttp/Promise/PromiseInterface.php',
  'GuzzleHttp\Promise\Is' => __DIR__ . '/GuzzleHttp/Promise/Is.php',
  'GuzzleHttp\Promise\Utils' => __DIR__ . '/GuzzleHttp/Promise/Utils.php',
  'GuzzleHttp\Promise\TaskQueueInterface' => __DIR__ . '/GuzzleHttp/Promise/TaskQueueInterface.php',
  'GuzzleHttp\Promise\functions' => __DIR__ . '/GuzzleHttp/Promise/functions.php',
  'GuzzleHttp\Promise\RejectionException' => __DIR__ . '/GuzzleHttp/Promise/RejectionException.php',
  'GuzzleHttp\Promise\Each' => __DIR__ . '/GuzzleHttp/Promise/Each.php',
  'GuzzleHttp\Promise\PromisorInterface' => __DIR__ . '/GuzzleHttp/Promise/PromisorInterface.php',
  'GuzzleHttp\Promise\RejectedPromise' => __DIR__ . '/GuzzleHttp/Promise/RejectedPromise.php',
  'GuzzleHttp\Promise\FulfilledPromise' => __DIR__ . '/GuzzleHttp/Promise/FulfilledPromise.php',
  'GuzzleHttp\Promise\Coroutine' => __DIR__ . '/GuzzleHttp/Promise/Coroutine.php',
  'GuzzleHttp\Promise\Create' => __DIR__ . '/GuzzleHttp/Promise/Create.php',
  'GuzzleHttp\Promise\Promise' => __DIR__ . '/GuzzleHttp/Promise/Promise.php',
  'GuzzleHttp\Promise\AggregateException' => __DIR__ . '/GuzzleHttp/Promise/AggregateException.php',
  
  'Aws\S3\MultipartUploader' => __DIR__ . '/Aws/S3/MultipartUploader.php',
  'Aws\S3\ObjectCopier' => __DIR__ . '/Aws/S3/ObjectCopier.php',
  'Aws\S3\BucketEndpointArnMiddleware' => __DIR__ . '/Aws/S3/BucketEndpointArnMiddleware.php',
  'Aws\S3\SSECMiddleware' => __DIR__ . '/Aws/S3/SSECMiddleware.php',
  'Aws\S3\MultipartUploadingTrait' => __DIR__ . '/Aws/S3/MultipartUploadingTrait.php',
  'Aws\S3\S3ClientInterface' => __DIR__ . '/Aws/S3/S3ClientInterface.php',
  'Aws\S3\GetBucketLocationParser' => __DIR__ . '/Aws/S3/GetBucketLocationParser.php',
  'Aws\S3\BucketEndpointMiddleware' => __DIR__ . '/Aws/S3/BucketEndpointMiddleware.php',
  'Aws\S3\PermanentRedirectMiddleware' => __DIR__ . '/Aws/S3/PermanentRedirectMiddleware.php',
  'Aws\S3\ObjectUploader' => __DIR__ . '/Aws/S3/ObjectUploader.php',
  'Aws\S3\Exception\DeleteMultipleObjectsException' => __DIR__ . '/Aws/S3/Exception/DeleteMultipleObjectsException.php',
  'Aws\S3\Exception\PermanentRedirectException' => __DIR__ . '/Aws/S3/Exception/PermanentRedirectException.php',
  'Aws\S3\Exception\S3Exception' => __DIR__ . '/Aws/S3/Exception/S3Exception.php',
  'Aws\S3\Exception\S3MultipartUploadException' => __DIR__ . '/Aws/S3/Exception/S3MultipartUploadException.php',
  'Aws\S3\CalculatesChecksumTrait' => __DIR__ . '/Aws/S3/CalculatesChecksumTrait.php',
  'Aws\S3\EndpointRegionHelperTrait' => __DIR__ . '/Aws/S3/EndpointRegionHelperTrait.php',
  'Aws\S3\Crypto\S3EncryptionMultipartUploaderV2' => __DIR__ . '/Aws/S3/Crypto/S3EncryptionMultipartUploaderV2.php',
  'Aws\S3\Crypto\S3EncryptionClient' => __DIR__ . '/Aws/S3/Crypto/S3EncryptionClient.php',
  'Aws\S3\Crypto\InstructionFileMetadataStrategy' => __DIR__ . '/Aws/S3/Crypto/InstructionFileMetadataStrategy.php',
  'Aws\S3\Crypto\S3EncryptionMultipartUploader' => __DIR__ . '/Aws/S3/Crypto/S3EncryptionMultipartUploader.php',
  'Aws\S3\Crypto\CryptoParamsTraitV2' => __DIR__ . '/Aws/S3/Crypto/CryptoParamsTraitV2.php',
  'Aws\S3\Crypto\UserAgentTrait' => __DIR__ . '/Aws/S3/Crypto/UserAgentTrait.php',
  'Aws\S3\Crypto\HeadersMetadataStrategy' => __DIR__ . '/Aws/S3/Crypto/HeadersMetadataStrategy.php',
  'Aws\S3\Crypto\S3EncryptionClientV2' => __DIR__ . '/Aws/S3/Crypto/S3EncryptionClientV2.php',
  'Aws\S3\Crypto\CryptoParamsTrait' => __DIR__ . '/Aws/S3/Crypto/CryptoParamsTrait.php',
  'Aws\S3\PostObjectV4' => __DIR__ . '/Aws/S3/PostObjectV4.php',
  'Aws\S3\S3ClientTrait' => __DIR__ . '/Aws/S3/S3ClientTrait.php',
  'Aws\S3\StreamWrapper' => __DIR__ . '/Aws/S3/StreamWrapper.php',
  'Aws\S3\S3Client' => __DIR__ . '/Aws/S3/S3Client.php',
  'Aws\S3\UseArnRegion\Exception\ConfigurationException' => __DIR__ . '/Aws/S3/UseArnRegion/Exception/ConfigurationException.php',
  'Aws\S3\UseArnRegion\ConfigurationInterface' => __DIR__ . '/Aws/S3/UseArnRegion/ConfigurationInterface.php',
  'Aws\S3\UseArnRegion\ConfigurationProvider' => __DIR__ . '/Aws/S3/UseArnRegion/ConfigurationProvider.php',
  'Aws\S3\UseArnRegion\Configuration' => __DIR__ . '/Aws/S3/UseArnRegion/Configuration.php',
  'Aws\S3\S3EndpointMiddleware' => __DIR__ . '/Aws/S3/S3EndpointMiddleware.php',
  'Aws\S3\BatchDelete' => __DIR__ . '/Aws/S3/BatchDelete.php',
  'Aws\S3\PostObject' => __DIR__ . '/Aws/S3/PostObject.php',
  'Aws\S3\PutObjectUrlMiddleware' => __DIR__ . '/Aws/S3/PutObjectUrlMiddleware.php',
  'Aws\S3\AmbiguousSuccessParser' => __DIR__ . '/Aws/S3/AmbiguousSuccessParser.php',
  'Aws\S3\MultipartCopy' => __DIR__ . '/Aws/S3/MultipartCopy.php',
  'Aws\S3\S3MultiRegionClient' => __DIR__ . '/Aws/S3/S3MultiRegionClient.php',
  'Aws\S3\ValidateResponseChecksumParser' => __DIR__ . '/Aws/S3/ValidateResponseChecksumParser.php',
  'Aws\S3\S3UriParser' => __DIR__ . '/Aws/S3/S3UriParser.php',
  'Aws\S3\RegionalEndpoint\Exception\ConfigurationException' => __DIR__ . '/Aws/S3/RegionalEndpoint/Exception/ConfigurationException.php',
  'Aws\S3\RegionalEndpoint\ConfigurationInterface' => __DIR__ . '/Aws/S3/RegionalEndpoint/ConfigurationInterface.php',
  'Aws\S3\RegionalEndpoint\ConfigurationProvider' => __DIR__ . '/Aws/S3/RegionalEndpoint/ConfigurationProvider.php',
  'Aws\S3\RegionalEndpoint\Configuration' => __DIR__ . '/Aws/S3/RegionalEndpoint/Configuration.php',
  'Aws\S3\RetryableMalformedResponseParser' => __DIR__ . '/Aws/S3/RetryableMalformedResponseParser.php',
  'Aws\S3\ApplyChecksumMiddleware' => __DIR__ . '/Aws/S3/ApplyChecksumMiddleware.php',
  'Aws\S3\Transfer' => __DIR__ . '/Aws/S3/Transfer.php',
  'Aws\Exception\CryptoPolyfillException' => __DIR__ . '/Aws/Exception/CryptoPolyfillException.php',
  'Aws\Exception\UnresolvedEndpointException' => __DIR__ . '/Aws/Exception/UnresolvedEndpointException.php',
  'Aws\Exception\CommonRuntimeException' => __DIR__ . '/Aws/Exception/CommonRuntimeException.php',
  'Aws\Exception\UnresolvedApiException' => __DIR__ . '/Aws/Exception/UnresolvedApiException.php',
  'Aws\Exception\MultipartUploadException' => __DIR__ . '/Aws/Exception/MultipartUploadException.php',
  'Aws\Exception\EventStreamDataException' => __DIR__ . '/Aws/Exception/EventStreamDataException.php',
  'Aws\Exception\CredentialsException' => __DIR__ . '/Aws/Exception/CredentialsException.php',
  'Aws\Exception\CouldNotCreateChecksumException' => __DIR__ . '/Aws/Exception/CouldNotCreateChecksumException.php',
  'Aws\Exception\UnresolvedSignatureException' => __DIR__ . '/Aws/Exception/UnresolvedSignatureException.php',
  'Aws\Exception\AwsException' => __DIR__ . '/Aws/Exception/AwsException.php',
  'Aws\Exception\CryptoException' => __DIR__ . '/Aws/Exception/CryptoException.php',
  'Aws\Exception\IncalculablePayloadException' => __DIR__ . '/Aws/Exception/IncalculablePayloadException.php',
  'Aws\Exception\InvalidRegionException' => __DIR__ . '/Aws/Exception/InvalidRegionException.php',
  'Aws\Exception\InvalidJsonException' => __DIR__ . '/Aws/Exception/InvalidJsonException.php',
  'Aws\AwsClient' => __DIR__ . '/Aws/AwsClient.php',
  'Aws\AwsClientInterface' => __DIR__ . '/Aws/AwsClientInterface.php',
  'Aws\AwsClientTrait' => __DIR__ . '/Aws/AwsClientTrait.php',
  'Aws\Api\ShapeMap' => __DIR__ . '/Aws/Api/ShapeMap.php',
  'Aws\Api\Parser\AbstractRestParser' => __DIR__ . '/Aws/Api/Parser/AbstractRestParser.php',
  'Aws\Api\Parser\XmlParser' => __DIR__ . '/Aws/Api/Parser/XmlParser.php',
  'Aws\Api\Parser\Exception\ParserException' => __DIR__ . '/Aws/Api/Parser/Exception/ParserException.php',
  'Aws\Api\Parser\PayloadParserTrait' => __DIR__ . '/Aws/Api/Parser/PayloadParserTrait.php',
  'Aws\Api\Parser\RestJsonParser' => __DIR__ . '/Aws/Api/Parser/RestJsonParser.php',
  'Aws\Api\Parser\AbstractParser' => __DIR__ . '/Aws/Api/Parser/AbstractParser.php',
  'Aws\Api\Parser\JsonRpcParser' => __DIR__ . '/Aws/Api/Parser/JsonRpcParser.php',
  'Aws\Api\Parser\QueryParser' => __DIR__ . '/Aws/Api/Parser/QueryParser.php',
  'Aws\Api\Parser\DecodingEventStreamIterator' => __DIR__ . '/Aws/Api/Parser/DecodingEventStreamIterator.php',
  'Aws\Api\Parser\JsonParser' => __DIR__ . '/Aws/Api/Parser/JsonParser.php',
  'Aws\Api\Parser\MetadataParserTrait' => __DIR__ . '/Aws/Api/Parser/MetadataParserTrait.php',
  'Aws\Api\Parser\EventParsingIterator' => __DIR__ . '/Aws/Api/Parser/EventParsingIterator.php',
  'Aws\Api\Parser\RestXmlParser' => __DIR__ . '/Aws/Api/Parser/RestXmlParser.php',
  'Aws\Api\Parser\Crc32ValidatingParser' => __DIR__ . '/Aws/Api/Parser/Crc32ValidatingParser.php',
  'Aws\Api\TimestampShape' => __DIR__ . '/Aws/Api/TimestampShape.php',
  'Aws\Api\Serializer\RestJsonSerializer' => __DIR__ . '/Aws/Api/Serializer/RestJsonSerializer.php',
  'Aws\Api\Serializer\QuerySerializer' => __DIR__ . '/Aws/Api/Serializer/QuerySerializer.php',
  'Aws\Api\Serializer\Ec2ParamBuilder' => __DIR__ . '/Aws/Api/Serializer/Ec2ParamBuilder.php',
  'Aws\Api\Serializer\RestXmlSerializer' => __DIR__ . '/Aws/Api/Serializer/RestXmlSerializer.php',
  'Aws\Api\Serializer\RestSerializer' => __DIR__ . '/Aws/Api/Serializer/RestSerializer.php',
  'Aws\Api\Serializer\JsonBody' => __DIR__ . '/Aws/Api/Serializer/JsonBody.php',
  'Aws\Api\Serializer\XmlBody' => __DIR__ . '/Aws/Api/Serializer/XmlBody.php',
  'Aws\Api\Serializer\QueryParamBuilder' => __DIR__ . '/Aws/Api/Serializer/QueryParamBuilder.php',
  'Aws\Api\Serializer\JsonRpcSerializer' => __DIR__ . '/Aws/Api/Serializer/JsonRpcSerializer.php',
  'Aws\Api\AbstractModel' => __DIR__ . '/Aws/Api/AbstractModel.php',
  'Aws\Api\ErrorParser\JsonParserTrait' => __DIR__ . '/Aws/Api/ErrorParser/JsonParserTrait.php',
  'Aws\Api\ErrorParser\JsonRpcErrorParser' => __DIR__ . '/Aws/Api/ErrorParser/JsonRpcErrorParser.php',
  'Aws\Api\ErrorParser\RestJsonErrorParser' => __DIR__ . '/Aws/Api/ErrorParser/RestJsonErrorParser.php',
  'Aws\Api\ErrorParser\XmlErrorParser' => __DIR__ . '/Aws/Api/ErrorParser/XmlErrorParser.php',
  'Aws\Api\ErrorParser\AbstractErrorParser' => __DIR__ . '/Aws/Api/ErrorParser/AbstractErrorParser.php',
  'Aws\Api\Operation' => __DIR__ . '/Aws/Api/Operation.php',
  'Aws\Api\Validator' => __DIR__ . '/Aws/Api/Validator.php',
  'Aws\Api\ApiProvider' => __DIR__ . '/Aws/Api/ApiProvider.php',
  'Aws\Api\Service' => __DIR__ . '/Aws/Api/Service.php',
  'Aws\Api\Shape' => __DIR__ . '/Aws/Api/Shape.php',
  'Aws\Api\DocModel' => __DIR__ . '/Aws/Api/DocModel.php',
  'Aws\Api\DateTimeResult' => __DIR__ . '/Aws/Api/DateTimeResult.php',
  'Aws\Api\MapShape' => __DIR__ . '/Aws/Api/MapShape.php',
  'Aws\Api\StructureShape' => __DIR__ . '/Aws/Api/StructureShape.php',
  'Aws\Api\ListShape' => __DIR__ . '/Aws/Api/ListShape.php',
  'Aws\AbstractConfigurationProvider' => __DIR__ . '/Aws/AbstractConfigurationProvider.php',
  'Aws\ConfigurationProviderInterface' => __DIR__ . '/Aws/ConfigurationProviderInterface.php',
  'Aws\Middleware' => __DIR__ . '/Aws/Middleware.php',
  'Aws\ClientSideMonitoring\Exception\ConfigurationException' => __DIR__ . '/Aws/ClientSideMonitoring/Exception/ConfigurationException.php',
  'Aws\ClientSideMonitoring\ApiCallAttemptMonitoringMiddleware' => __DIR__ . '/Aws/ClientSideMonitoring/ApiCallAttemptMonitoringMiddleware.php',
  'Aws\ClientSideMonitoring\MonitoringMiddlewareInterface' => __DIR__ . '/Aws/ClientSideMonitoring/MonitoringMiddlewareInterface.php',
  'Aws\ClientSideMonitoring\ConfigurationInterface' => __DIR__ . '/Aws/ClientSideMonitoring/ConfigurationInterface.php',
  'Aws\ClientSideMonitoring\AbstractMonitoringMiddleware' => __DIR__ . '/Aws/ClientSideMonitoring/AbstractMonitoringMiddleware.php',
  'Aws\ClientSideMonitoring\ConfigurationProvider' => __DIR__ . '/Aws/ClientSideMonitoring/ConfigurationProvider.php',
  'Aws\ClientSideMonitoring\ApiCallMonitoringMiddleware' => __DIR__ . '/Aws/ClientSideMonitoring/ApiCallMonitoringMiddleware.php',
  'Aws\ClientSideMonitoring\Configuration' => __DIR__ . '/Aws/ClientSideMonitoring/Configuration.php',
  'Aws\InputValidationMiddleware' => __DIR__ . '/Aws/InputValidationMiddleware.php',
  'Aws\Arn\ArnParser' => __DIR__ . '/Aws/Arn/ArnParser.php',
  'Aws\Arn\AccessPointArnInterface' => __DIR__ . '/Aws/Arn/AccessPointArnInterface.php',
  'Aws\Arn\Exception\InvalidArnException' => __DIR__ . '/Aws/Arn/Exception/InvalidArnException.php',
  'Aws\Arn\ObjectLambdaAccessPointArn' => __DIR__ . '/Aws/Arn/ObjectLambdaAccessPointArn.php',
  'Aws\Arn\ArnInterface' => __DIR__ . '/Aws/Arn/ArnInterface.php',
  'Aws\Arn\S3\MultiRegionAccessPointArn' => __DIR__ . '/Aws/Arn/S3/MultiRegionAccessPointArn.php',
  'Aws\Arn\S3\OutpostsAccessPointArn' => __DIR__ . '/Aws/Arn/S3/OutpostsAccessPointArn.php',
  'Aws\Arn\S3\OutpostsBucketArn' => __DIR__ . '/Aws/Arn/S3/OutpostsBucketArn.php',
  'Aws\Arn\S3\BucketArnInterface' => __DIR__ . '/Aws/Arn/S3/BucketArnInterface.php',
  'Aws\Arn\S3\OutpostsArnInterface' => __DIR__ . '/Aws/Arn/S3/OutpostsArnInterface.php',
  'Aws\Arn\S3\AccessPointArn' => __DIR__ . '/Aws/Arn/S3/AccessPointArn.php',
  'Aws\Arn\Arn' => __DIR__ . '/Aws/Arn/Arn.php',
  'Aws\Arn\AccessPointArn' => __DIR__ . '/Aws/Arn/AccessPointArn.php',
  'Aws\Arn\ResourceTypeAndIdTrait' => __DIR__ . '/Aws/Arn/ResourceTypeAndIdTrait.php',
  'Aws\Endpoint\UseDualstackEndpoint\Exception\ConfigurationException' => __DIR__ . '/Aws/Endpoint/UseDualstackEndpoint/Exception/ConfigurationException.php',
  'Aws\Endpoint\UseDualstackEndpoint\ConfigurationInterface' => __DIR__ . '/Aws/Endpoint/UseDualstackEndpoint/ConfigurationInterface.php',
  'Aws\Endpoint\UseDualstackEndpoint\ConfigurationProvider' => __DIR__ . '/Aws/Endpoint/UseDualstackEndpoint/ConfigurationProvider.php',
  'Aws\Endpoint\UseDualstackEndpoint\Configuration' => __DIR__ . '/Aws/Endpoint/UseDualstackEndpoint/Configuration.php',
  'Aws\Endpoint\PartitionEndpointProvider' => __DIR__ . '/Aws/Endpoint/PartitionEndpointProvider.php',
  'Aws\Endpoint\PartitionInterface' => __DIR__ . '/Aws/Endpoint/PartitionInterface.php',
  'Aws\Endpoint\UseFipsEndpoint\Exception\ConfigurationException' => __DIR__ . '/Aws/Endpoint/UseFipsEndpoint/Exception/ConfigurationException.php',
  'Aws\Endpoint\UseFipsEndpoint\ConfigurationInterface' => __DIR__ . '/Aws/Endpoint/UseFipsEndpoint/ConfigurationInterface.php',
  'Aws\Endpoint\UseFipsEndpoint\ConfigurationProvider' => __DIR__ . '/Aws/Endpoint/UseFipsEndpoint/ConfigurationProvider.php',
  'Aws\Endpoint\UseFipsEndpoint\Configuration' => __DIR__ . '/Aws/Endpoint/UseFipsEndpoint/Configuration.php',
  'Aws\Endpoint\Partition' => __DIR__ . '/Aws/Endpoint/Partition.php',
  'Aws\Endpoint\PatternEndpointProvider' => __DIR__ . '/Aws/Endpoint/PatternEndpointProvider.php',
  'Aws\Endpoint\EndpointProvider' => __DIR__ . '/Aws/Endpoint/EndpointProvider.php',
  'Aws\HasDataTrait' => __DIR__ . '/Aws/HasDataTrait.php',
  'Aws\EndpointParameterMiddleware' => __DIR__ . '/Aws/EndpointParameterMiddleware.php',
  'Aws\RetryMiddleware' => __DIR__ . '/Aws/RetryMiddleware.php',
  'Aws\Retry\Exception\ConfigurationException' => __DIR__ . '/Aws/Retry/Exception/ConfigurationException.php',
  'Aws\Retry\RetryHelperTrait' => __DIR__ . '/Aws/Retry/RetryHelperTrait.php',
  'Aws\Retry\ConfigurationInterface' => __DIR__ . '/Aws/Retry/ConfigurationInterface.php',
  'Aws\Retry\ConfigurationProvider' => __DIR__ . '/Aws/Retry/ConfigurationProvider.php',
  'Aws\Retry\RateLimiter' => __DIR__ . '/Aws/Retry/RateLimiter.php',
  'Aws\Retry\Configuration' => __DIR__ . '/Aws/Retry/Configuration.php',
  'Aws\Retry\QuotaManager' => __DIR__ . '/Aws/Retry/QuotaManager.php',
  'Aws\Sdk' => __DIR__ . '/Aws/Sdk.php',
  'Aws\Credentials\EcsCredentialProvider' => __DIR__ . '/Aws/Credentials/EcsCredentialProvider.php',
  'Aws\Credentials\CredentialsInterface' => __DIR__ . '/Aws/Credentials/CredentialsInterface.php',
  'Aws\Credentials\CredentialProvider' => __DIR__ . '/Aws/Credentials/CredentialProvider.php',
  'Aws\Credentials\AssumeRoleCredentialProvider' => __DIR__ . '/Aws/Credentials/AssumeRoleCredentialProvider.php',
  'Aws\Credentials\InstanceProfileProvider' => __DIR__ . '/Aws/Credentials/InstanceProfileProvider.php',
  'Aws\Credentials\Credentials' => __DIR__ . '/Aws/Credentials/Credentials.php',
  'Aws\DefaultsMode\Exception\ConfigurationException' => __DIR__ . '/Aws/DefaultsMode/Exception/ConfigurationException.php',
  'Aws\DefaultsMode\ConfigurationInterface' => __DIR__ . '/Aws/DefaultsMode/ConfigurationInterface.php',
  'Aws\DefaultsMode\ConfigurationProvider' => __DIR__ . '/Aws/DefaultsMode/ConfigurationProvider.php',
  'Aws\DefaultsMode\Configuration' => __DIR__ . '/Aws/DefaultsMode/Configuration.php',
  'Aws\Handler\GuzzleV6\GuzzleHandler' => __DIR__ . '/Aws/Handler/GuzzleV6/GuzzleHandler.php',
  'Aws\Handler\GuzzleV5\GuzzleHandler' => __DIR__ . '/Aws/Handler/GuzzleV5/GuzzleHandler.php',
  'Aws\Handler\GuzzleV5\PsrStream' => __DIR__ . '/Aws/Handler/GuzzleV5/PsrStream.php',
  'Aws\Handler\GuzzleV5\GuzzleStream' => __DIR__ . '/Aws/Handler/GuzzleV5/GuzzleStream.php',
  'Aws\CacheInterface' => __DIR__ . '/Aws/CacheInterface.php',
  'Aws\EndpointDiscovery\EndpointList' => __DIR__ . '/Aws/EndpointDiscovery/EndpointList.php',
  'Aws\EndpointDiscovery\Exception\ConfigurationException' => __DIR__ . '/Aws/EndpointDiscovery/Exception/ConfigurationException.php',
  'Aws\EndpointDiscovery\ConfigurationInterface' => __DIR__ . '/Aws/EndpointDiscovery/ConfigurationInterface.php',
  'Aws\EndpointDiscovery\ConfigurationProvider' => __DIR__ . '/Aws/EndpointDiscovery/ConfigurationProvider.php',
  'Aws\EndpointDiscovery\Configuration' => __DIR__ . '/Aws/EndpointDiscovery/Configuration.php',
  'Aws\EndpointDiscovery\EndpointDiscoveryMiddleware' => __DIR__ . '/Aws/EndpointDiscovery/EndpointDiscoveryMiddleware.php',
  'Aws\Result' => __DIR__ . '/Aws/Result.php',
  'Aws\WrappedHttpHandler' => __DIR__ . '/Aws/WrappedHttpHandler.php',
  'Aws\StreamRequestPayloadMiddleware' => __DIR__ . '/Aws/StreamRequestPayloadMiddleware.php',
  'Aws\Command' => __DIR__ . '/Aws/Command.php',
  'Aws\HandlerList' => __DIR__ . '/Aws/HandlerList.php',
  'Aws\ResultInterface' => __DIR__ . '/Aws/ResultInterface.php',
  'Aws\Signature\SignatureInterface' => __DIR__ . '/Aws/Signature/SignatureInterface.php',
  'Aws\Signature\SignatureV4' => __DIR__ . '/Aws/Signature/SignatureV4.php',
  'Aws\Signature\S3SignatureV4' => __DIR__ . '/Aws/Signature/S3SignatureV4.php',
  'Aws\Signature\SignatureTrait' => __DIR__ . '/Aws/Signature/SignatureTrait.php',
  'Aws\Signature\SignatureProvider' => __DIR__ . '/Aws/Signature/SignatureProvider.php',
  'Aws\Signature\AnonymousSignature' => __DIR__ . '/Aws/Signature/AnonymousSignature.php',
  'Aws\ResponseContainerInterface' => __DIR__ . '/Aws/ResponseContainerInterface.php',
  'Aws\CommandInterface' => __DIR__ . '/Aws/CommandInterface.php',
  'Aws\MonitoringEventsInterface' => __DIR__ . '/Aws/MonitoringEventsInterface.php',
  'Aws\IdempotencyTokenMiddleware' => __DIR__ . '/Aws/IdempotencyTokenMiddleware.php',
  'Aws\LruArrayCache' => __DIR__ . '/Aws/LruArrayCache.php',
  'Aws\HasMonitoringEventsTrait' => __DIR__ . '/Aws/HasMonitoringEventsTrait.php',
  'Aws\ClientResolver' => __DIR__ . '/Aws/ClientResolver.php',
  
  'Psr\Http\Message\UploadedFileInterface' => __DIR__ . '/Psr/Http/Message/UploadedFileInterface.php',
  'Psr\Http\Message\MessageInterface' => __DIR__ . '/Psr/Http/Message/MessageInterface.php',
  'Psr\Http\Message\ServerRequestInterface' => __DIR__ . '/Psr/Http/Message/ServerRequestInterface.php',
  'Psr\Http\Message\UriInterface' => __DIR__ . '/Psr/Http/Message/UriInterface.php',
  'Psr\Http\Message\RequestInterface' => __DIR__ . '/Psr/Http/Message/RequestInterface.php',
  'Psr\Http\Message\StreamInterface' => __DIR__ . '/Psr/Http/Message/StreamInterface.php',
  'Psr\Http\Message\ResponseInterface' => __DIR__ . '/Psr/Http/Message/ResponseInterface.php',
  'Symfony\Polyfill\Intl\Idn\Idn' => __DIR__ . '/Symfony/Polyfill/Intl/Idn/Idn.php',
  'Symfony\Polyfill\Intl\Idn\Resources\unidata\deviation' => __DIR__ . '/Symfony/Polyfill/Intl/Idn/Resources/unidata/deviation.php',
  'Symfony\Polyfill\Intl\Idn\Resources\unidata\virama' => __DIR__ . '/Symfony/Polyfill/Intl/Idn/Resources/unidata/virama.php',
  'Symfony\Polyfill\Intl\Idn\Resources\unidata\disallowed_STD3_valid' => __DIR__ . '/Symfony/Polyfill/Intl/Idn/Resources/unidata/disallowed_STD3_valid.php',
  'Symfony\Polyfill\Intl\Idn\Resources\unidata\Regex' => __DIR__ . '/Symfony/Polyfill/Intl/Idn/Resources/unidata/Regex.php',
  'Symfony\Polyfill\Intl\Idn\Resources\unidata\disallowed' => __DIR__ . '/Symfony/Polyfill/Intl/Idn/Resources/unidata/disallowed.php',
  'Symfony\Polyfill\Intl\Idn\Resources\unidata\disallowed_STD3_mapped' => __DIR__ . '/Symfony/Polyfill/Intl/Idn/Resources/unidata/disallowed_STD3_mapped.php',
  'Symfony\Polyfill\Intl\Idn\Resources\unidata\DisallowedRanges' => __DIR__ . '/Symfony/Polyfill/Intl/Idn/Resources/unidata/DisallowedRanges.php',
  'Symfony\Polyfill\Intl\Idn\Resources\unidata\mapped' => __DIR__ . '/Symfony/Polyfill/Intl/Idn/Resources/unidata/mapped.php',
  'Symfony\Polyfill\Intl\Idn\Resources\unidata\ignored' => __DIR__ . '/Symfony/Polyfill/Intl/Idn/Resources/unidata/ignored.php',
  'Symfony\Polyfill\Intl\Idn\Info' => __DIR__ . '/Symfony/Polyfill/Intl/Idn/Info.php',
  'Symfony\Polyfill\Intl\Idn\bootstrap' => __DIR__ . '/Symfony/Polyfill/Intl/Idn/bootstrap.php',
  'JmesPath\Env' => __DIR__ . '/JmesPath/Env.php',
  'JmesPath\TreeInterpreter' => __DIR__ . '/JmesPath/TreeInterpreter.php',
  'JmesPath\JmesPath' => __DIR__ . '/JmesPath/JmesPath.php',
  'JmesPath\AstRuntime' => __DIR__ . '/JmesPath/AstRuntime.php',
  'JmesPath\Parser' => __DIR__ . '/JmesPath/Parser.php',
  'JmesPath\Utils' => __DIR__ . '/JmesPath/Utils.php',
  'JmesPath\TreeCompiler' => __DIR__ . '/JmesPath/TreeCompiler.php',
  'JmesPath\Lexer' => __DIR__ . '/JmesPath/Lexer.php',
  'JmesPath\DebugRuntime' => __DIR__ . '/JmesPath/DebugRuntime.php',
  'JmesPath\FnDispatcher' => __DIR__ . '/JmesPath/FnDispatcher.php',
  'JmesPath\SyntaxErrorException' => __DIR__ . '/JmesPath/SyntaxErrorException.php',
  'JmesPath\CompilerRuntime' => __DIR__ . '/JmesPath/CompilerRuntime.php',
  
  'Aws\Sns\SnsClient' => __DIR__ . '/Aws/Sns/SnsClient.php',
  'Aws\Sns\Exception\SnsException' => __DIR__ . '/Aws/Sns/Exception/SnsException.php',
  'Aws\Sns\Exception\InvalidSnsMessageException' => __DIR__ . '/Aws/Sns/Exception/InvalidSnsMessageException.php',
  'Aws\Sns\MessageValidator' => __DIR__ . '/Aws/Sns/MessageValidator.php',
  'Aws\Sns\Message' => __DIR__ . '/Aws/Sns/Message.php',
  
  'Aws\data\sns\2010-03-31\api-2.json' => __DIR__ . '/Aws/data/sns/2010-03-31/api-2.json.php',
  'Aws\data\sns\2010-03-31\paginators-1.json' => __DIR__ . '/Aws/data/sns/2010-03-31/paginators-1.json.php',
  'Aws\data\sns\2010-03-31\endpoint-rule-set-1.json' => __DIR__ . '/Aws/data/sns/2010-03-31/endpoint-rule-set-1.json.php',
  'Aws\data\sns\2010-03-31\smoke.json' => __DIR__ . '/Aws/data/sns/2010-03-31/smoke.json.php',
  'Aws\data\sns\2010-03-31\endpoint-tests-1.json' => __DIR__ . '/Aws/data/sns/2010-03-31/endpoint-tests-1.json.php',
);

spl_autoload_register(function ($class) use ($mapping) {
  if (isset($mapping[$class])) {
      require $mapping[$class];
  }
}, true);

require __DIR__ . '/Aws/functions.php';
require __DIR__ . '/GuzzleHttp/functions_include.php';
require __DIR__ . '/GuzzleHttp/Psr7/functions_include.php';
require __DIR__ . '/GuzzleHttp/Promise/functions_include.php';
require __DIR__ . '/JmesPath/JmesPath.php';
require __DIR__ . '/Symfony/Polyfill/Intl/Idn/bootstrap.php';
